/* UPSSTAT.CMD */
/* Written by Lone Peak Automation, LLC  */
/* This program gets the UPS status from UPSDAEM.EXE once every second */

/* This program uses named shared memory to interface to UPSDAEM.EXE
   The external REXX library RXU.DLL is required. RXU can be found on Hobbes. */

/* Needed for SysSleep */
call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
call SysLoadFuncs

/* Load RXU.DLL */
call rxfuncadd 'rxuinit','rxu','rxuinit'
call rxuinit

SAY 'Poll UPSDAEM every 2 seconds. Press CTRL-BREAK to quit.'

/* To get named shared memory */
getrc = RxGetNamedSharedMem('pointer', '\SHAREMEM\UPSDAEM\UPSSTATUS', 'r')

DO FOREVER
   IF getrc = 0 THEN
       UPSStat = RxStorage( pointer, 2)   /* get two bytes from shared memory */
   ELSE
     DO
       SAY 'UPSDaemon not loaded. Program ended.'  /* UPS Daemon not loaded, exit */
       LEAVE
     END

   SELECT
     WHEN POS('3', UPSStat) > 0 THEN
       temp = "Normal"
     WHEN UPSStat = '12' THEN
       temp = "Power Fail"
     WHEN UPSStat = '48' | upsstat = '51' THEN
       temp = "Low Battery"
     WHEN UPSStat = '60' THEN
       temp = "Low Battery and Power Fail"
     OTHERWISE
       temp = ''
   END

   SAY 'UPS Status is: ' || UPSStat || ' ' || temp

   CALL SysSleep(2)   /* wait for two seconds */

END /* Do While */

/* free Named Shared Memory */
/* this is a must!!! */
freerc = RxFreeMem(pointer)

EXIT